package com.ruoyi.szxc.service;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcWorkGuide;

/**
 * 办事指南Service接口
 * 
 * @author hs
 * @date 2024-03-20
 */
public interface ISzxcWorkGuideService 
{
    /**
     * 查询办事指南
     * 
     * @param id 办事指南主键
     * @return 办事指南
     */
    public SzxcWorkGuide selectSzxcWorkGuideById(Long id);

    /**
     * 查询办事指南列表
     * 
     * @param szxcWorkGuide 办事指南
     * @return 办事指南集合
     */
    public List<SzxcWorkGuide> selectSzxcWorkGuideList(SzxcWorkGuide szxcWorkGuide);

    /**
     * 新增办事指南
     * 
     * @param szxcWorkGuide 办事指南
     * @return 结果
     */
    public int insertSzxcWorkGuide(SzxcWorkGuide szxcWorkGuide);

    /**
     * 修改办事指南
     * 
     * @param szxcWorkGuide 办事指南
     * @return 结果
     */
    public int updateSzxcWorkGuide(SzxcWorkGuide szxcWorkGuide);

    /**
     * 批量删除办事指南
     * 
     * @param ids 需要删除的办事指南主键集合
     * @return 结果
     */
    public int deleteSzxcWorkGuideByIds(Long[] ids);

    /**
     * 删除办事指南信息
     * 
     * @param id 办事指南主键
     * @return 结果
     */
    public int deleteSzxcWorkGuideById(Long id);
}
